
LOG_FORMAT = "%(asctime)s:  %(levelname)s:  %(message)s"

DEFAULT_CONFIGURATION = { "project_path" : "", 
                        "feeder_name" : "GWC",
                        "log_settings": {
                                    "save_in_file": False,
                                    "log_folder": "",
                                    "log_filename":"",
                                    "clear_old_log_file": True
                                    },
                        "PV_customers_step" : 10,
                        "PV_capacity_step" : 1,
                        "number_of_monte_carlo_run" : 1,
                        "export_pickle_for_risk_analysis" : "yes",
                        "time_series_pf" : "yes",
                        "num_of_data_points" : 35040,
                        "minute-interval" : 15,
                        "time_series_voltage_profile" : "yes",
                        "voltage_csv_name" : "voltagemult.csv",
                        "sourcebasekv" : 33.0,
                        "sourcebasefreq" : 50,
                        "sourcepu" : 1.0,
                        "sourcezeroseq_impedance" : [0.001,0.001],
                        "sourceposseq_impedance" : [0.001,0.001],
                        "source_num_of_phase" : 3,
                        "include_PV" : "yes",
                        "PV_volt_label" : [0.44,0.23],
                        "annual_PV_capacity_factor" : 0.25,
                        "inverter_oversize_factor" : 0.9,
                        "max_pu_irradiance" : 0.98,
                        "no_reactive_support_from_PV" : "yes",
                        "PV_cutin" : 0.05,
                        "PV_cutout" : 0.05,
                        "solar_csvname" : "solarmult.csv",
                        "three_phase" : "RYB",
                        "single_phase" : ["R","Y","B"],
                        "random_phase_allocation" : "yes",
                        "multi_threephase_for_lt" : "yes",
                        "num_of_parallel_three_phase" : 3,
                        "servicewire_phase_conductor_type" : "AAAC",
                        "servicewire_phase_conductor_size" : "4.0",
                        "phase_conductor_type_ht_consumer" : "RABBIT",
                        "phase_conductor_size_ht_consumer" : "7/3.35",
                        "service_wire_spacing" : "vertical",
                        "ht_consumer_conductor_spacing" : "vertical",
                        "units_for_coordinate" : "m",
                        "service_wire_num_of_cond" : {
                            "single_phase" : 2,
                            "three_phase" : 4
                        },
                        "ht_consumer_conductor_num_of_cond": {"three_phase" : 3},
                        "phase2num" :{"R" : 1,"Y" : 2,"B" : 3}
                    }

VALID_SETTINGS = { "project_path" : {'type':str}, 
                        "feeder_name" : {'type':str},
                        "log_settings": {
                                    "save_in_file": {'type':bool},
                                    "log_folder": {'type':str},
                                    "log_filename": {'type':str},
                                    "clear_old_log_file": {'type': bool}
                                    },
                        "PV_customers_step" : {'type': int},
                        "PV_capacity_step" : {'type': int},
                        "number_of_monte_carlo_run" : {'type': int},
                        "export_pickle_for_risk_analysis" : {'type':str, 'options':["yes","no"]},
                        "time_series_pf" : {'type':str, 'options':["yes","no"]},
                        "num_of_data_points" : {'type':int},
                        "minute-interval" : {'type':int},
                        "time_series_voltage_profile" : {'type':str, 'options':["yes","no"]},
                        "voltage_csv_name" : {'type':str},
                        "sourcebasekv" : {'type':float},
                        "sourcebasefreq" : {'type':int, 'options':[50,60]},
                        "sourcepu" : {'type':float},
                        "sourcezeroseq_impedance" : {'type': list},
                        "sourceposseq_impedance" : {'type': list},
                        "source_num_of_phase" : {'type': int},
                        "include_PV" : {'type':str, 'options':["yes","no"]},
                        "PV_volt_label" : {'type': list},
                        "annual_PV_capacity_factor" : {'type':float},
                        "inverter_oversize_factor" : {'type':float},
                        "max_pu_irradiance" : {'type':float},
                        "no_reactive_support_from_PV" : {'type':str, 'options':["yes","no"]},
                        "PV_cutin" : {'type':float},
                        "PV_cutout" : {'type':float},
                        "solar_csvname" : {'type':str},
                        "three_phase" : {'type':str},
                        "single_phase" : {'type': list},
                        "random_phase_allocation" : {'type':str, 'options':["yes","no"]},
                        "multi_threephase_for_lt" : {'type':str, 'options':["yes","no"]},
                        "num_of_parallel_three_phase" : {'type':int},
                        "servicewire_phase_conductor_type" : {'type':str},
                        "servicewire_phase_conductor_size" : {'type':str},
                        "phase_conductor_type_ht_consumer" : {'type':str},
                        "phase_conductor_size_ht_consumer" :{'type':str},
                        "service_wire_spacing" : {'type':str, 'options':['vertical','horizontal']},
                        "ht_consumer_conductor_spacing" : {'type':str,'options':['vertical','horizontal']},
                        "units_for_coordinate" : {"type":str},
                        "service_wire_num_of_cond" : {
                            "single_phase" : {'type':int},
                            "three_phase" : {'type':int}
                        },
                        "ht_consumer_conductor_num_of_cond": {"three_phase" : {'type':int,'options':[1,2,3]}},
                        "phase2num" :{  "R" : {'type':int,'options':[1,2,3]},
                                        "Y" : {'type':int,'options':[1,2,3]},
                                        "B" : {'type':int,'options':[1,2,3]}}
                    }